.. _modules:

package details
===========================================

Team Scraper
------------

.. automodule:: usau_scraper.teamScraper
   :members:
   :show-inheritance:

Tournament Scraper
------------------

.. automodule:: usau_scraper.tournamentScraper
   :members:
   :show-inheritance:
   
Rankings Scraper
-----------------
.. automodule:: usau_scraper.rankingScraper
   :members:
   :show-inheritance:
